"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.loader = void 0;
var _nodePath = require("node:path");
var _schemaUtils = require("schema-utils");
var _magicComments = require("magic-comments");
var _schema = require("./schema.cjs");
var _parser = require("./parser.cjs");
var _formatter = require("./formatter.cjs");
var _comment = require("./comment.cjs");
const loader = function (source) {
  const options = this.getOptions();
  const logger = this.getLogger('MCL');
  (0, _schemaUtils.validate)(_schema.schema, options, {
    name: 'magic-comments-loader'
  });
  const {
    mode = 'parser',
    match = 'module',
    comments = 'ignore',
    verbose = false,
    ...rest
  } = options;
  const magicCommentOptions = Object.keys(rest).length ? rest : {
    webpackChunkName: true
  };
  const filepath = this.resourcePath;
  if (mode === 'parser') {
    const [magicSource, magicImports] = (0, _formatter.format)({
      ...(0, _parser.parse)(source),
      match,
      filepath,
      comments,
      magicCommentOptions
    });
    if (verbose) {
      const relativePath = (0, _nodePath.relative)(this.rootContext, filepath);
      magicImports.forEach(magicImport => {
        logger.info(`${relativePath} : ${magicImport}`);
      });
    }
    return magicSource;
  }
  return source.replace(_magicComments.dynamicImportsWithoutComments, (0, _comment.getCommenter)(filepath, {
    verbose,
    match,
    magicCommentOptions
  }, logger));
};
exports.loader = loader;