"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.parse = void 0;
var _acorn = require("acorn");
var _acornWalk = require("acorn-walk");
var _acornJsxWalk = require("acorn-jsx-walk");
var _acornJsx = _interopRequireDefault(require("acorn-jsx"));
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
/**
 * NOTE: Side-effect of importing this module's exports.
 *
 * Extend acorn-walk's base with missing JSX nodes.
 * @see https://github.com/acornjs/acorn/issues/829
 *
 * Consider another parser that supports more syntaxes out-of-the-box.
 * That would enable less requirements on loader chaining.
 */
(0, _acornJsxWalk.extend)(_acornWalk.base);
const jsxParser = _acorn.Parser.extend((0, _acornJsx.default)());
const parse = source => {
  const astComments = [];
  const importExpressionNodes = [];
  const ast = jsxParser.parse(source, {
    locations: false,
    ecmaVersion: 2023,
    sourceType: 'module',
    allowAwaitOutsideFunction: true,
    allowReturnOutsideFunction: true,
    allowImportExportEverywhere: true,
    onComment: (isBlock, text, start, end) => {
      if (isBlock) {
        astComments.push({
          start,
          end,
          text
        });
      }
    }
  });
  (0, _acornWalk.simple)(ast, {
    ImportExpression(node) {
      importExpressionNodes.push(node);
    }
  });
  return {
    ast,
    astComments,
    importExpressionNodes,
    source
  };
};
exports.parse = parse;